@@ -236,7 +236,10 @@ AudioRenderer.prototype = {
             this._toolbarPlay.set_icon_name('media-playback-pause-symbolic');
             break;
         default:
-            this._toolbarPlay.set_icon_name('media-playback-start-symbolic');
+            let iconName =
+            (this._toolbarPlay.get_direction() == Gtk.TextDirection.RTL) ?
+                'media-playback-start-rtl-symbolic' : 'media-playback-start-symbolic';
+            this._toolbarPlay.set_icon_name(iconName);
         }
     },
 
